@@ -3,6 +3,7 @@ from recipys.ArgParser import ArgParser
 from recipys.ConsolePrinter import ConsolePrinter
 from recipys.RecipeFetcher import RecipeFetcher
 from recipys.request_wait import wait_for_green_light
+from recipys.types import PrintInterrupt
 
 
 def main():
@@ -10,11 +11,14 @@ def main():
 
     wait_for_green_light()
 
-    recipe_constraints = ArgParser(sys.argv).parse()
-
-    recipe = RecipeFetcher(recipe_constraints).fetch()
-
-    ConsolePrinter(recipe).print_recipe()
+    try:
+        recipe_constraints = ArgParser(sys.argv).parse()
+    except PrintInterrupt as e:
+        recipe = e.printable
+    else:
+        recipe = RecipeFetcher(recipe_constraints).fetch()
+    finally:
+        ConsolePrinter(recipe).print_recipe()
 
 
 if __name__ == "__main__":
